@@ -2,7 +2,7 @@ from datetime import datetime
 
 from tests.base import BaseTestCase
 
-from home.ts.models import Series, Device, DataPoint
+from home.ts.models import Area, Series, Device, DataPoint, DeviceSeries
 
 
 class SeriesModelTestCase(BaseTestCase):
@@ -23,7 +23,8 @@ class DeviceModelTestCase(BaseTestCase):
     def setUp(self):
         super().setUp()
 
-        self.device = Device(82, 1, '0xAAAA', name="Test device")
+        self.area = Area(name="livingroom")
+        self.device = Device(82, 1, '0xAAAA', area=self.area)
         self.insert(self.device)
 
     def test_repr(self):
@@ -39,9 +40,10 @@ class DataPointModelTestCase(BaseTestCase):
         now = datetime.now()
 
         self.series = Series(name="series_a")
-        self.device = Device(82, 1, '0xAAAA', name="device_a")
-        self.data_point = DataPoint(
-            self.series, self.device, 10, created_at=now)
+        self.area = Area(name="livingroom")
+        self.device = Device(82, 1, '0xAAAA', area=self.area)
+        self.device_series = DeviceSeries(self.device, self.series)
+        self.data_point = DataPoint(self.device_series, 10, created_at=now)
 
         self.insert(self.device)
         self.insert(self.series)
